@@ -5,6 +5,7 @@ from uuid import UUID
 
 import pytest
 from sanic.exceptions import SanicException
+from sanic.views import HTTPMethodView
 
 from sanic_ext import openapi
 
@@ -405,7 +406,7 @@ def test_tag_decorator(app, decorator, tags):
     assert list(tagged) == list(tags)
 
 
-def test_definition_decorator_body_dict(app):
+def test_definition_decorator_body_dict_w_obj(app):
     @app.route("/")
     @openapi.definition(body={"application/json": Bar})
     async def handler(_):
@@ -424,6 +425,67 @@ def test_definition_decorator_body_dict(app):
     }
 
 
+def test_definition_decorator_body_dict_only_schema_head(app):
+    @app.route("/")
+    @openapi.definition(
+        body={
+            "application/json": {
+                "schema": {
+                    "type": "object",
+                    "properties": {"name": {"type": "string"}},
+                }
+            }
+        }
+    )
+    async def handler(_):
+        ...
+
+    body = get_path(app, "/")["requestBody"]
+    assert body == {
+        "content": {
+            "application/json": {
+                "schema": {
+                    "type": "object",
+                    "properties": {"name": {"type": "string"}},
+                }
+            }
+        }
+    }
+
+
+def test_definition_decorator_body_dict_only_schema_root(app):
+    @app.route("/")
+    @openapi.definition(
+        body={
+            "application/json": {
+                "type": "object",
+                "properties": {"name": {"type": "string"}},
+            }
+        }
+    )
+    async def handler(_):
+        ...
+
+
+def test_definition_decorator_httpmethodview(app):
+    class View(HTTPMethodView, uri="/", attach=app):
+        @openapi.definition(body={"application/json": Bar})
+        async def get(self, request):
+            ...
+
+    body = get_path(app, "/")["requestBody"]
+    assert body == {
+        "content": {
+            "application/json": {
+                "schema": {
+                    "type": "object",
+                    "properties": {"name": {"type": "string"}},
+                }
+            }
+        }
+    }
+
+
 def test_definition_decorator_body_dict_multi(app):
     @app.route("/")
     @openapi.definition(body={"application/json": Bar, "text/plain": str})
